@@ -1,19 +1,26 @@
 from datetime import datetime
 from enum import Enum
-from typing import Any, Dict, Optional, Union
+from typing import Any, Dict, List, Optional, Union
 
 from pydantic import BaseModel, Field, SecretStr
 
 from ..log import STDOUT
+from ..plugin_config import AccountConfig
 
 
 class ProcessAccount(BaseModel):
+    source: AccountConfig
     uin: int
     password: Optional[SecretStr] = None
     config: Dict[str, Any] = Field(default_factory=dict)
     device: Dict[str, Any] = Field(default_factory=dict)
 
 
+class ProcessAccountsStore(BaseModel):
+    accounts: List[AccountConfig]
+    created_at: datetime = Field(default_factory=datetime.now)
+
+
 class ProcessLogLevel(str, Enum):
     STDOUT = STDOUT.name
 
@@ -39,7 +46,6 @@ class RunningProcessDetail(BaseModel):
     pid: int
     status: str
     memory_used: int
-    swap_used: int
     cpu_percent: float
     start_time: float
 
@@ -52,4 +58,5 @@ class ProcessInfo(BaseModel):
     status: ProcessStatus
     total_logs: int
     restarts: int
+    qr_uri: Optional[str] = None
     details: Union[RunningProcessDetail, StoppedProcessDetail]
